#!/usr/bin/env python

"""To load templates."""

from distutils.dir_util import copy_tree
from flask.ext.script import prompt, prompt_choices
from os.path import abspath

def main():
  choice = int(prompt_choices(
    'What would you like to do',
    [
      ('1', 'Load example 1'),
      ('2', 'Load example 2'),
      ('3', 'Load example 3'),
      ('0', 'Exit'),
    ],
    resolve=lambda e: str(e)
  ))
  if choice > 0:
    directory = abspath(prompt('In which directory', default='.'))
    print 'Copying example %s...' % choice
    copy_tree()

if __name__ == '__main__':
  main()



#!/usr/bin/env python

from flask.ext.script import Manager, prompt, Shell

class ProjectManager(object):

  def __init__(self, project):

    manager = Manager(project.make, with_default_commands=False)

    # these options seem to be passed to the make_app function and
    # also added  to the current_app instance
    manager.add_option(
        '-d', '--debug', action='store_true', dest='debug', default=False
    )

    # Shell

    manager.add_command('shell', Shell())

    @manager.shell
    def make_shell_context():
      project.db.create_connection()
      return {'app': project.app, 'db': project.db, 'celery': project.celery}

    # Server

    @manager.option('-t', '--host', dest='host', default='0.0.0.0')
    @manager.option('-p', '--port', dest='port', default=5000)
    def run_server(host, port):
      """Start the flask werkzeug server."""
      project.db.create_connection(app=project.app)
      project.app.run(host=host, port=int(port), debug=project.app.debug)

    @manager.command
    def view_app_config():
      """View config currently used by the app."""
      print 'App config:'
      for key, value in sorted(project.app.config.items()):
        print '%30s %s' % (key, value)

    # OAuth

    if project.use_oauth():

      @manager.command
      def add_user():
        """Add user to database."""
        project.db.create_connection()
        with project.db as session:
          user_email = prompt('User email?')
          user = oauth.User(user_email)
          session.add(user)

      @manager.command
      def view_users():
        """View all database users."""
        project.db.create_connection()
        with project.db as session:
          users = session.query(oauth.User).all()
          for user in users:
            print '%10s %s' % (user.id, user.email)

      @manager.command
      def remove_user():
        """Remove user."""
        project.db.create_connection()
        with project.db as session:
          users = session.query(oauth.User).all()
          for user in users:
            print '%10s %s' % (user.id, user.email)
          user_id = prompt('User id?')
          session.delete(oauth.User.query.get(user_id))

    # Celery

    @manager.command
    def run_worker():
      """Start the Celery worker."""
      hostname = project.NAME.lower().replace(' ', '_')
      if project.app.debug:
        project.celery.worker_main([
          'worker',
          '--beat',
          '--schedule=%s/production.sch' % project.CELERY_SCHEDULE_FOLDER,
          '--hostname=development.%s' % hostname,
          '--queues=development'
        ])
      else:
        project.celery.worker_main([
          'worker',
          '--beat',
          '--schedule=%s/development.sch' % project.CELERY_SCHEDULE_FOLDER,
          '--hostname=production.%s' % hostname,
          '--queues=production'
        ])

    # Flower

    @manager.option('-p', '--port', dest='port', default='5555')
    def run_flower(port):
      """Run flow manager."""
      project.celery.start([
        'celery',
        'flower',
        '--broker=%s' % project.celery.conf['BROKER_URL'],
        '--port=%s' % port
      ])

    self.manager = manager

  def run(self):
    self.manager.run()




#!/usr/bin/env python

from logging import getLogger
from logging.config import dictConfig
from os.path import abspath, dirname, join, split
from sys import modules
from weakref import proxy
from werkzeug.local import LocalProxy

from . import config

logger = getLogger()

class BaseProject(object):

  """Base project class.

  All folder paths indicated here are relative to the folder where the project
  class is defined.

  """

  __current__ = None

  NAME = None
  MODULES = None
  DB_URL = None
  LOGGING_FOLDER = 'logs'
  APP_STATIC_FOLDER = 'static'
  APP_TEMPLATE_FOLDER = 'templates'
  CELERY_SCHEDULE_FOLDER = 'celery'
  APP_CONFIG = config.AppConfig
  CELERY_CONFIG = config.CeleryConfig
  LOGGER_CONFIG = config.LoggerConfig
  STATIC_URL = None
  OAUTH_GOOGLE_CLIENT = None

  def __init__(self):

    # BaseProject must be subclassed to gain access to project directory
    if not self.NAME:
      raise Exception("Subclass necessary.")
    else:
      assert BaseProject.__current__ is None, 'More than one project.'
      BaseProject.__current__ = proxy(self)

    # Making all paths absolute
    root_dir = abspath(dirname(modules[self.__class__.__module__].__file__))
    self.root_dir = root_dir
    self.LOGGING_FOLDER = join(root_dir, self.LOGGING_FOLDER)
    self.APP_STATIC_FOLDER = join(root_dir, self.APP_STATIC_FOLDER)
    self.APP_TEMPLATE_FOLDER = join(root_dir, self.APP_TEMPLATE_FOLDER)
    self.CELERY_SCHEDULE_FOLDER = join(root_dir, self.CELERY_SCHEDULE_FOLDER)
    if self.DB_URL is None:
      self.DB_URL = 'sqlite:///%s' % join(root_dir, 'db', 'db.sqlite')

    # Currently, 3 components to a project
    self.app = None
    self.celery = None
    self.db = None

  def __repr__(self):
    return '<%s %r (%r)>' % (self.__class__.__name__, self.NAME, self.root_dir)

  def use_oauth(self):
    return bool(self.OAUTH_GOOGLE_CLIENT)

  def make(self, debug=False):
    self.debug = debug
    self.logger = logger
    dictConfig(self.LOGGER_CONFIG.generate(self))
    __import__('flasker.components.app')
    __import__('flasker.components.database')
    __import__('flasker.components.celery')
    if self.MODULES:
      map(
        __import__, 
        ['%s.%s' % (split(self.root_dir)[1], mod) for mod in self.MODULES]
      )
    return self.app

  @classmethod
  def get_current_project(cls):
    return BaseProject.__current__

current_project = LocalProxy(lambda: BaseProject.get_current_project())



#!/usr/bin/env python

from setuptools import find_packages, setup

setup(
    name='flasker',
    version='0.1.1',
    description='Flasker',
    long_description=open('README.rst').read(),
    author='Matthieu Monsch',
    author_email='monsch@mit.edu',
    url='https://github.com/mtth/flasker',
    license='MIT',
    packages=find_packages(),
    install_requires=[
      'celery',
      'flask',
      'flask-script',
      'flask-login',
      'sqlalchemy',
      'redis',
      'flower'
    ],
    package_data={'flasker': ['components/templates/*']},
    data_files=[
      ('example', ['example/manage.py']),
      ('example/app', [
        'example/app/project.py',
        'example/app/views.py',
        'example/app/__init__.py',
      ])
    ]
)
